import glob
import numpy as np
import pandas as pd
import pyhande
import matplotlib.pyplot as plt

results = {}
for fname in glob.glob('calcs/fciqmc/hubbard_fciqmc*out'):
    out = pyhande.lazy.std_analysis([fname], start=30000, extract_psips=True)[0]
    res = out.opt_block.loc['Proj. Energy', 'mean':'standard error']
    res['wall_time'] = out.metadata['wall_time']
    if out.metadata['qmc']['real_amplitudes']:
        results[out.metadata['qmc']['spawn_cutoff']] = res
    else:
        results[1.0] = res
results = pd.DataFrame(results).T

# todo - legend, axis labels
(fig, ax1) = plt.subplots()
lines1 = ax1.plot(results.index, 10**5*results['standard error'], 'x-', label='standard error')
ax1.set_xlabel('spawn cutoff')
ax1.set_ylabel(r'standard error / $10^{-5}$ [$U/t$]')

ax2 = ax1.twinx()
try:
    ax2._get_lines.color_cycle.next()
except AttributeError:
    next(ax2._get_lines.prop_cycler)
lines2 = ax2.plot(results.index, results['wall_time'], 'x-', label='wall time')
ax2.set_yticks(np.linspace(ax2.get_yticks()[0],ax2.get_yticks()[-1],len(ax1.get_yticks())))
ax2.set_ylabel('wall time [s]')

lines = lines1 + lines2
labels = [l.get_label() for l in lines]
ax1.legend(lines, labels, loc='center right')